==> haskell-servant-client-0.20.3.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-5s7zGzfAItOB4ZzFrtUduz
key:                  servant-client-0.20.3.0-5s7zGzfAItOB4ZzFrtUduz
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  839546d4e77ef5684440a02b69b1123b
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-5s7zGzfAItOB4ZzFrtUduz
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-media-0.8.1.1-F5mdsuADoqm1fkscHywvqG
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    kan-extensions-5.2.7-A9uRk27W33o9Gv66XLFDqp
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl mtl-2.2.2
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR
    servant-0.20.3.0-GOIaCeayVrDJ22GgZs5cgj
    servant-client-core-0.20.3.0-ElEnQUK02Oe3ydbQ9eDBFI stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20.3.0-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-FQJcxzQHMgZ43pa5N5fjmb
key:                  servant-client-0.20.3.0-FQJcxzQHMgZ43pa5N5fjmb
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  0dcadff5c70b8cf127639da45b5263f9
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-FQJcxzQHMgZ43pa5N5fjmb
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-media-0.8.1.1-75g3Noac7YSCbog0lXG15E
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    kan-extensions-5.2.7-CIi5Vc911l99QFwa6aOcgC
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs mtl-2.2.2
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J
    servant-0.20.3.0-5yfHPrFnFIjC5udvdKPgHT
    servant-client-core-0.20.3.0-168OqtrGYus1cDAOzzAo5H stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
